exportPattern("^[^\\.]")
importFrom("grDevices", "cairo_pdf", "chull", "dev.copy","dev.copy2pdf", "dev.new", "dev.off", "png")
importFrom("graphics", "contour", "hist", "layout", "legend", "pairs","par", "plot.new", "rect", "strwidth", "text")
importFrom("stats", "cor", "median", "quantile", "runif", "sd")
importFrom("utils", "capture.output", "installed.packages", "read.csv", "read.table")
